@@ -390,6 +390,7 @@ void dai_choose_paratrooper(struct ai_type *ait,
   int num_requirements = 0;
   int i;
   struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
+  const struct civ_map *nmap = &(wld.map);
 
   /* military_advisor_choose_build() does something idiotic,
    * this function should not be called if there is danger... */
@@ -432,7 +433,7 @@ void dai_choose_paratrooper(struct ai_type *ait,
     }
 
     /* we only update choice struct if we can build it! */
-    if (!can_city_build_unit_now(pcity, u_type)) {
+    if (!can_city_build_unit_now(nmap, pcity, u_type)) {
       continue;
     }
 
