@@ -201,15 +201,16 @@ static bool apply_result_on_server(struct city *pcity,
   connection_do_buffer(&client.conn);
 
   /* Remove all surplus workers */
-  city_tile_iterate_skip_free_worked(city_radius_sq, pcenter, ptile, idx,
-                                     x, y) {
+  city_tile_iterate_skip_free_worked(&(wld.map), city_radius_sq, pcenter,
+                                     ptile, idx, x, y) {
     if (tile_worked(ptile) == pcity
         && !result->worker_positions[idx]) {
       log_apply_result("Removing worker at {%d,%d}.", x, y);
 
       last_request_id =
         dsend_packet_city_make_specialist(&client.conn,
-                                          pcity->id, ptile->index);
+                                          pcity->id, pcity->id,
+                                          ptile->index);
       if (first_request_id == 0) {
         first_request_id = last_request_id;
       }
@@ -240,7 +241,7 @@ static bool apply_result_on_server(struct city *pcity,
   /* Set workers */
   /* FIXME: This code assumes that any toggled worker will turn into a
    * DEFAULT_SPECIALIST! */
-  city_tile_iterate_skip_free_worked(city_radius_sq, pcenter, ptile, idx,
+  city_tile_iterate_skip_free_worked(&(wld.map), city_radius_sq, pcenter, ptile, idx,
                                      x, y) {
     if (NULL == tile_worked(ptile)
         && result->worker_positions[idx]) {
@@ -249,7 +250,7 @@ static bool apply_result_on_server(struct city *pcity,
 
       last_request_id =
         dsend_packet_city_make_worker(&client.conn,
-                                      pcity->id, ptile->index);
+                                      pcity->id, pcity->id, ptile->index);
       if (first_request_id == 0) {
         first_request_id = last_request_id;
       }
@@ -285,8 +286,8 @@ static bool apply_result_on_server(struct city *pcity,
        * allocation of citizen than the server. We just send a
        * PACKET_CITY_REFRESH to bring them in sync.
        */
-    first_request_id = last_request_id =
-      dsend_packet_city_refresh(&client.conn, pcity->id);
+    first_request_id = last_request_id
+      = dsend_packet_city_refresh(&client.conn, pcity->id, pcity->id);
     stats.refresh_forced++;
   }
 
