@@ -42,7 +42,7 @@
 #include "climisc.h"
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "diplodlg.h"
 #include "gui_main.h"
 #include "gui_stuff.h"
@@ -155,7 +155,7 @@ void handle_diplomacy_cancel_meeting(int counterpart, int initiated_from)
   Added clause to the meeting
 ****************************************************************************/
 void handle_diplomacy_create_clause(int counterpart, int giver,
-                                    enum clause_type type, int value)
+				    enum clause_type type, int value)
 {
   struct Diplomacy_dialog *pdialog = find_diplomacy_dialog(counterpart);
 
@@ -166,7 +166,7 @@ void handle_diplomacy_create_clause(int counterpart, int giver,
   add_clause(&pdialog->treaty, player_by_number(giver), type, value,
              client_player());
   update_diplomacy_dialog(pdialog);
-  gui_dialog_alert(pdialog->dialog);
+  gui_dialog_alert(pdialog->dialog);  
 }
 
 /************************************************************************//**
@@ -187,7 +187,7 @@ void handle_diplomacy_remove_clause(int counterpart, int giver,
 }
 
 /************************************************************************//**
-  Popup the dialog 10% inside the main-window 
+  Popup the dialog 10% inside the main-window
 ****************************************************************************/
 static void popup_diplomacy_dialog(int other_player_id, int initiated_from)
 {
@@ -203,7 +203,7 @@ static void popup_diplomacy_dialog(int other_player_id, int initiated_from)
 
   if (!pdialog) {
     pdialog = create_diplomacy_dialog(client.conn.playing,
-				      player_by_number(other_player_id));
+                                      player_by_number(other_player_id));
   }
 
   gui_dialog_present(pdialog->dialog);
@@ -336,7 +336,8 @@ static void popup_add_menu(GtkMenuShell *parent, gpointer data)
       for (list_item = sorting_list; NULL != list_item;
            list_item = g_list_next(list_item)) {
         padvance = (const struct advance *) list_item->data;
-        item = gtk_menu_item_new_with_label(advance_name_translation(padvance));
+        item =
+            gtk_menu_item_new_with_label(advance_name_translation(padvance));
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
         g_object_set_data(G_OBJECT(item), "player_from",
                           GINT_TO_POINTER(player_number(pgiver)));
@@ -354,6 +355,7 @@ static void popup_add_menu(GtkMenuShell *parent, gpointer data)
     gtk_widget_show_all(advance_item);
   }
 
+
   /* Trading: cities. */
 
   /****************************************************************
@@ -492,7 +494,7 @@ static void popup_add_menu(GtkMenuShell *parent, gpointer data)
   Some clause activated
 ****************************************************************************/
 static void row_callback(GtkTreeView *view, GtkTreePath *path,
-			 GtkTreeViewColumn *col, gpointer data)
+                         GtkTreeViewColumn *col, gpointer data)
 {
   struct Diplomacy_dialog *pdialog = (struct Diplomacy_dialog *)data;
   gint i;
@@ -504,10 +506,10 @@ static void row_callback(GtkTreeView *view, GtkTreePath *path,
   clause_list_iterate(pdialog->treaty.clauses, pclause) {
     if (i == index[0]) {
       dsend_packet_diplomacy_remove_clause_req(&client.conn,
-					       player_number(pdialog->treaty.plr1),
-					       player_number(pclause->from),
-					       pclause->type,
-					       pclause->value);
+                                               player_number(pdialog->treaty.plr1),
+                                               player_number(pclause->from),
+                                               pclause->type,
+                                               pclause->value);
       return;
     }
     i++;
@@ -539,9 +541,9 @@ static struct Diplomacy_notebook *diplomacy_main_create(void)
     gtk_container_add(GTK_CONTAINER(dipl_sw), dipl_main->notebook);
 
     /* Buttons */
-    gui_dialog_add_button(dipl_main->dialog, NULL,
-                          _("Cancel _all meetings"),
-                          RESPONSE_CANCEL_MEETING_ALL);
+    gui_dialog_add_stockbutton(dipl_main->dialog, GTK_STOCK_CANCEL,
+                               _("Cancel _all meetings"),
+                               RESPONSE_CANCEL_MEETING_ALL);
 
     /* Responses for _all_ meetings. */
     gui_dialog_response_set_callback(dipl_main->dialog,
@@ -696,10 +698,10 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   gui_dialog_new(&(pdialog->dialog), GTK_NOTEBOOK(notebook), pdialog, FALSE);
 
   /* Buttons */
-  gui_dialog_add_button(pdialog->dialog, NULL,
-                        _("Accept treaty"), GTK_RESPONSE_ACCEPT);
-  gui_dialog_add_button(pdialog->dialog, NULL,
-                        _("Cancel meeting"), RESPONSE_CANCEL_MEETING);
+  gui_dialog_add_stockbutton(pdialog->dialog, GTK_STOCK_DND,
+                             _("Accept treaty"), GTK_RESPONSE_ACCEPT);
+  gui_dialog_add_stockbutton(pdialog->dialog, GTK_STOCK_CANCEL,
+                             _("Cancel meeting"), RESPONSE_CANCEL_MEETING);
 
   /* Responses for one meeting. */
   gui_dialog_response_set_callback(pdialog->dialog, diplomacy_response);
@@ -778,7 +780,10 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   menu = gtk_menu_new();
   pdialog->menu0 = menu;
 
-  menuitem = gtk_menu_item_new_with_label(_("Add Clause..."));
+  menuitem = gtk_image_menu_item_new_with_label(_("Add Clause..."));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem),
+                                gtk_image_new_from_stock(GTK_STOCK_ADD,
+                                                         GTK_ICON_SIZE_MENU));
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), menu);
   gtk_menu_shell_append(GTK_MENU_SHELL(menubar), menuitem);
   g_object_set_data(G_OBJECT(menu), "plr", plr0);
@@ -860,7 +865,10 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   menu = gtk_menu_new();
   pdialog->menu1 = menu;
 
-  menuitem = gtk_menu_item_new_with_label(_("Add Clause..."));
+  menuitem = gtk_image_menu_item_new_with_label(_("Add Clause..."));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem),
+                                gtk_image_new_from_stock(GTK_STOCK_ADD,
+                                                         GTK_ICON_SIZE_MENU));
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), menu);
   gtk_menu_shell_append(GTK_MENU_SHELL(menubar), menuitem);
   g_object_set_data(G_OBJECT(menu), "plr", plr1);
@@ -1047,7 +1055,7 @@ static void diplomacy_dialog_city_callback(GtkWidget *w, gpointer data)
   }
 
   dsend_packet_diplomacy_create_clause_req(&client.conn, other, deal_data->giver,
-                                           CLAUSE_CITY, deal_data->id);
+					   CLAUSE_CITY, deal_data->id);
 
   free(deal_data);
 }
@@ -1059,7 +1067,7 @@ static void diplomacy_dialog_map_callback(GtkWidget *w, gpointer data)
 {
   struct Diplomacy_dialog *pdialog = (struct Diplomacy_dialog *)data;
   struct player *pgiver;
-
+  
   pgiver = (struct player *)g_object_get_data(G_OBJECT(w), "plr");
 
   dsend_packet_diplomacy_create_clause_req(&client.conn,
@@ -1074,7 +1082,7 @@ static void diplomacy_dialog_seamap_callback(GtkWidget *w, gpointer data)
 {
   struct Diplomacy_dialog *pdialog = (struct Diplomacy_dialog *)data;
   struct player *pgiver;
-
+  
   pgiver = (struct player *)g_object_get_data(G_OBJECT(w), "plr");
 
   dsend_packet_diplomacy_create_clause_req(&client.conn,
@@ -1092,9 +1100,9 @@ static void diplomacy_dialog_add_pact_clause(GtkWidget *w, gpointer data,
   struct Diplomacy_dialog *pdialog = (struct Diplomacy_dialog *)data;
 
   dsend_packet_diplomacy_create_clause_req(&client.conn,
-                                           player_number(pdialog->treaty.plr1),
-                                           player_number(pdialog->treaty.plr0),
-                                           type, 0);
+					   player_number(pdialog->treaty.plr1),
+					   player_number(pdialog->treaty.plr0),
+					   type, 0);
 }
 
 /************************************************************************//**
