@@ -47,7 +47,7 @@
 #include "options.h"
 #include "tilespec.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-3.22 */
 #include "colors.h"
 #include "graphics.h"
 #include "gui_main.h"
@@ -245,10 +245,10 @@ static void create_tech_tree(int tech, int levels, GtkTreeIter *parent)
     g_value_unset(&value);
 
     gtk_tree_store_set(tstore, &l,
-		       1, -1,
-		       2, tech,
-		       3, &get_color(tileset, bg)->color
-		       -1);
+                       1, -1,
+                       2, tech,
+                       3, &get_color(tileset, bg)->color
+                       -1);
     return;
   }
 
@@ -286,13 +286,14 @@ static void create_tech_tree(int tech, int levels, GtkTreeIter *parent)
   g_value_unset(&value);
 
   gtk_tree_store_set(tstore, &l,
-		     1, turns_to_tech,
-		     2, tech,
-		     3, &get_color(tileset, bg)->color,
-		     -1);
+                     1, turns_to_tech,
+                     2, tech,
+                     3, &get_color(tileset, bg)->color,
+                     -1);
 
-  if (--levels <= 0)
-      return;
+  if (--levels <= 0) {
+    return;
+  }
 
   if (original) {
     /* only add children to orginals */
@@ -308,9 +309,9 @@ static void create_tech_tree(int tech, int levels, GtkTreeIter *parent)
   Selects the help page for the tech in the tree that was double clicked.
 **************************************************************************/
 static void help_tech_tree_activated_callback(GtkTreeView *view,
-					      GtkTreePath *path,
-					      GtkTreeViewColumn *col,
-					      gpointer data)
+                                              GtkTreePath *path,
+                                              GtkTreeViewColumn *col,
+                                              gpointer data)
 {
   GtkTreeIter it;
   gint tech;
@@ -485,8 +486,7 @@ static void activated_topic(GtkTreeView *view, gpointer data)
   gtk_tree_model_get(model, &it, 1, &pitem, -1);
 
   if (help_history_pos >= 0
-      && g_ptr_array_index(help_history, help_history_pos)
-      == (gpointer) pitem) {
+      && g_ptr_array_index(help_history, help_history_pos) == (gpointer) pitem) {
     return;
   }
 
@@ -521,18 +521,18 @@ static void create_help_dialog(void)
   help_history_pos = -1;
 
   help_dialog_shell = gtk_dialog_new_with_buttons(_("Freeciv Help Browser"),
-						  NULL,
-						  0,
-						  GTK_STOCK_GO_BACK,
-						  1,
-						  GTK_STOCK_GO_FORWARD,
-						  2,
-						  GTK_STOCK_CLOSE,
-						  GTK_RESPONSE_CLOSE,
-						  NULL);
+                                                  NULL,
+                                                  0,
+                                                  _("_Back"),
+                                                  1,
+                                                  _("_Forward"),
+                                                  2,
+                                                  _("_Close"),
+                                                  GTK_RESPONSE_CLOSE,
+                                                  NULL);
   setup_dialog(help_dialog_shell, toplevel);
   gtk_dialog_set_default_response(GTK_DIALOG(help_dialog_shell),
-				  GTK_RESPONSE_CLOSE);
+                                  GTK_RESPONSE_CLOSE);
   gtk_widget_set_name(help_dialog_shell, "Freeciv");
 
   g_signal_connect(help_dialog_shell, "response",
@@ -611,7 +611,6 @@ static void create_help_dialog(void)
   gtk_container_add(GTK_CONTAINER(help_frame), help_box);
 
   help_tile = gtk_image_new();
-
   gtk_container_add(GTK_CONTAINER(help_box), help_tile);
 
   help_itable = gtk_grid_new();
@@ -988,7 +987,7 @@ static void help_update_wonder(const struct help_item *pitem,
   Display updated help about unit type
 **************************************************************************/
 static void help_update_unit_type(const struct help_item *pitem,
-				  char *title)
+                                  char *title)
 {
   char buf[8192];
   struct unit_type *utype = unit_type_by_translated_name(title);
@@ -1058,8 +1057,9 @@ static char *fc_chomp(char *str, size_t len)
 {
   gchar *i;
 
-  if (!str || !*str)
+  if (!str || !*str) {
     return str;
+  }
 
   i = str + len;
   for (i = g_utf8_find_prev_char(str, i);
