@@ -809,27 +809,33 @@ bool is_action_enabled_unit_on_extras(const struct civ_map *nmap,
                                       const struct tile *target,
                                       const struct extra_type *tgt_extra);
 
-bool is_action_enabled_unit_on_self(const action_id wanted_action,
+bool is_action_enabled_unit_on_self(const struct civ_map *nmap,
+                                    const action_id wanted_action,
                                     const struct unit *actor_unit);
 
-struct act_prob action_prob_vs_city(const struct unit* actor,
+struct act_prob action_prob_vs_city(const struct civ_map *nmap,
+                                    const struct unit *actor,
                                     const action_id act_id,
-                                    const struct city* victim);
+                                    const struct city *victim);
 
-struct act_prob action_prob_vs_unit(const struct unit* actor,
+struct act_prob action_prob_vs_unit(const struct civ_map *nmap,
+                                    const struct unit *actor,
                                     const action_id act_id,
-                                    const struct unit* victim);
+                                    const struct unit *victim);
 
-struct act_prob action_prob_vs_units(const struct unit* actor,
+struct act_prob action_prob_vs_units(const struct civ_map *nmap,
+                                     const struct unit* actor,
                                      const action_id act_id,
                                      const struct tile* victims);
 
-struct act_prob action_prob_vs_tile(const struct unit *actor,
+struct act_prob action_prob_vs_tile(const struct civ_map *nmap,
+                                    const struct unit *actor,
                                     const action_id act_id,
                                     const struct tile *victims,
                                     const struct extra_type *target_extra);
 
-struct act_prob action_prob_vs_extras(const struct unit *actor,
+struct act_prob action_prob_vs_extras(const struct civ_map *nmap,
+                                      const struct unit *actor,
                                       const action_id act_id,
                                       const struct tile *target,
                                       const struct extra_type *tgt_extra);
