@@ -572,7 +572,7 @@ bool city_celebrating(const struct city *pcity);            /* love the king ???
 bool city_rapture_grow(const struct city *pcity);
 bool city_is_occupied(const struct city *pcity);
 
-/* city related improvement and unit functions */
+/* City related improvement and unit functions */
 
 int city_improvement_upkeep(const struct city *pcity,
                             const struct impr_type *pimprove);
@@ -584,11 +584,14 @@ bool can_city_build_improvement_later(const struct city *pcity,
 bool can_city_build_improvement_now(const struct city *pcity,
                                     const struct impr_type *pimprove);
 
-bool can_city_build_unit_direct(const struct city *pcity,
+bool can_city_build_unit_direct(const struct civ_map *nmap,
+                                const struct city *pcity,
                                 const struct unit_type *punittype);
-bool can_city_build_unit_later(const struct city *pcity,
+bool can_city_build_unit_later(const struct civ_map *nmap,
+                               const struct city *pcity,
                                const struct unit_type *punittype);
-bool can_city_build_unit_now(const struct city *pcity,
+bool can_city_build_unit_now(const struct civ_map *nmap,
+                             const struct city *pcity,
                              const struct unit_type *punittype);
 
 bool can_city_build_direct(const struct city *pcity,
@@ -632,13 +635,13 @@ bool city_can_change_build(const struct city *pcity);
 
 void city_choose_build_default(struct city *pcity);
 
-/* textual representation of buildings */
+/* Textual representation of buildings */
 
 const char *city_improvement_name_translation(const struct city *pcity,
 					      const struct impr_type *pimprove);
 const char *city_production_name_translation(const struct city *pcity);
 
-/* city map functions */
+/* City map functions */
 bool is_valid_city_coords(const int city_radius_sq, const int city_map_x,
                           const int city_map_y);
 bool city_map_includes_tile(const struct city *const pcity,
@@ -676,7 +679,8 @@ bool city_can_work_tile(const struct city *pcity, const struct tile *ptile);
 bool citymindist_prevents_city_on_tile(const struct civ_map *nmap,
                                        const struct tile *ptile);
 
-bool city_can_be_built_here(const struct tile *ptile,
+bool city_can_be_built_here(const struct civ_map *nmap,
+                            const struct tile *ptile,
                             const struct unit *punit,
                             bool hut_test);
 bool city_can_be_built_tile_only(const struct civ_map *nmap,
@@ -743,8 +747,10 @@ static inline bool is_non_allied_city_tile(const struct tile *ptile,
   return NULL != tile_non_allied_city(ptile, pplayer);
 }
 
-bool is_unit_near_a_friendly_city(const struct unit *punit);
-bool is_friendly_city_near(const struct player *owner,
+bool is_unit_near_a_friendly_city(const struct civ_map *nmap,
+                                  const struct unit *punit);
+bool is_friendly_city_near(const struct civ_map *nmap,
+                           const struct player *owner,
                            const struct tile *ptile);
 bool city_exists_within_max_city_map(const struct tile *ptile,
                                      bool may_be_on_center);
