@@ -685,8 +685,8 @@ void conn_reset_delta_state(struct connection *pc)
 
 /**********************************************************************//**
   Freeze the connection. Then the packets sent to it won't be sent
-  immediately, but later, using a compression method. See futher details in
-  common/packets.[ch].
+  immediately, but later, using a compression method. See further details
+  in common/networking/packets.[ch].
 **************************************************************************/
 void conn_compression_freeze(struct connection *pconn)
 {
