@@ -316,7 +316,9 @@ enum unit_airlift_result
                              const struct player *restriction,
                              const struct unit *punit,
                              const struct city *pdest_city);
-bool unit_can_airlift_to(const struct unit *punit, const struct city *pcity);
+bool unit_can_airlift_to(const struct civ_map *nmap,
+                         const struct unit *punit, const struct city *pcity)
+  fc__attribute((nonnull (3)));
 bool unit_has_orders(const struct unit *punit);
 
 bool could_unit_be_in_transport(const struct unit *pcargo,
@@ -473,7 +475,8 @@ static inline bool is_my_zoc(const struct player *unit_owner, const struct tile
     ? is_plr_zoc_srv(unit_owner, ptile, zmap) : is_plr_zoc_client(unit_owner, ptile, zmap);
 }
 
-bool unit_being_aggressive(const struct unit *punit);
+bool unit_being_aggressive(const struct civ_map *nmap,
+                           const struct unit *punit);
 bool unit_type_really_ignores_zoc(const struct unit_type *punittype);
 
 bool is_build_activity(enum unit_activity activity);
