@@ -597,6 +597,8 @@ void action_consequence_complete(const struct action *paction,
 static bool may_unit_act_vs_city(struct unit *actor, struct city *target,
                                  bool accept_all_actions)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   if (actor == NULL || target == NULL) {
     /* Can't do any actions if actor or target are missing. */
     return FALSE;
@@ -614,7 +616,7 @@ static bool may_unit_act_vs_city(struct unit *actor, struct city *target,
       continue;
     }
 
-    if (action_prob_possible(action_prob_vs_city(actor, act, target))) {
+    if (action_prob_possible(action_prob_vs_city(nmap, actor, act, target))) {
       /* The actor unit may be able to do this action to the target
        * city. */
       return TRUE;
@@ -661,6 +663,8 @@ struct city *action_tgt_city(struct unit *actor, struct tile *target_tile,
 static bool may_unit_act_vs_unit(struct unit *actor, struct unit *target,
                                  bool accept_all_actions)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   if (actor == NULL || target == NULL) {
     /* Can't do any actions if actor or target are missing. */
     return FALSE;
@@ -678,7 +682,7 @@ static bool may_unit_act_vs_unit(struct unit *actor, struct unit *target,
       continue;
     }
 
-    if (action_prob_possible(action_prob_vs_unit(actor, act, target))) {
+    if (action_prob_possible(action_prob_vs_unit(nmap, actor, act, target))) {
       /* The actor unit may be able to do this action to the target
        * unit. */
       return TRUE;
@@ -729,6 +733,8 @@ struct tile *action_tgt_tile(struct unit *actor,
                              const struct extra_type *target_extra,
                              bool accept_all_actions)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   if (actor == NULL || target == NULL) {
     /* Can't do any actions if actor or target are missing. */
     return NULL;
@@ -749,13 +755,13 @@ struct tile *action_tgt_tile(struct unit *actor,
 
     switch (action_id_get_target_kind(act)) {
     case ATK_TILE:
-      prob = action_prob_vs_tile(actor, act, target, target_extra);
+      prob = action_prob_vs_tile(nmap, actor, act, target, target_extra);
       break;
     case ATK_EXTRAS:
-      prob = action_prob_vs_extras(actor, act, target, target_extra);
+      prob = action_prob_vs_extras(nmap, actor, act, target, target_extra);
       break;
     case ATK_UNITS:
-      prob = action_prob_vs_units(actor, act, target);
+      prob = action_prob_vs_units(nmap, actor, act, target);
       break;
     case ATK_CITY:
     case ATK_UNIT:
@@ -795,6 +801,8 @@ static bool may_unit_act_vs_tile_extra(const struct unit *actor,
                                        const struct extra_type *tgt_extra,
                                        bool accept_all_actions)
 {
+  const struct civ_map *nmap = &(wld.map);
+
   if (actor == NULL || tgt_tile == NULL || tgt_extra == NULL) {
     /* Can't do any actions if actor or target are missing. */
     return FALSE;
@@ -816,7 +824,7 @@ static bool may_unit_act_vs_tile_extra(const struct unit *actor,
 
     switch (action_id_get_target_kind(act)) {
     case ATK_TILE:
-      if (action_prob_possible(action_prob_vs_tile(actor, act,
+      if (action_prob_possible(action_prob_vs_tile(nmap, actor, act,
                                                    tgt_tile, tgt_extra))) {
         /* The actor unit may be able to do this action to the target
          * extra. */
@@ -824,7 +832,7 @@ static bool may_unit_act_vs_tile_extra(const struct unit *actor,
       }
       break;
     case ATK_EXTRAS:
-      if (action_prob_possible(action_prob_vs_extras(actor, act,
+      if (action_prob_possible(action_prob_vs_extras(nmap, actor, act,
                                                      tgt_tile,
                                                      tgt_extra))) {
         /* The actor unit may be able to do this action to the target
@@ -880,6 +888,7 @@ int action_sub_target_id_for_action(const struct action *paction,
                                     struct unit *actor_unit)
 {
   const struct tile *tgt_tile = unit_tile(actor_unit);
+  const struct civ_map *nmap = &(wld.map);
 
   fc_assert_ret_val(paction->target_complexity == ACT_TGT_COMPL_FLEXIBLE,
                     NO_TARGET);
@@ -904,7 +913,7 @@ int action_sub_target_id_for_action(const struct action *paction,
   case ASTK_EXTRA_NOT_THERE:
     if (action_has_result(paction, ACTRES_PILLAGE)) {
       /* Special treatment for "Pillage" */
-      struct extra_type *pextra;
+      struct extra_type *pextra = NULL;
       enum unit_activity activity = actres_get_activity(paction->result);
 
       unit_assign_specific_activity_target(actor_unit, &activity, &pextra);
@@ -914,7 +923,7 @@ int action_sub_target_id_for_action(const struct action *paction,
       }
     }
     extra_type_re_active_iterate(tgt_extra) {
-      if (action_prob_possible(action_prob_vs_tile(actor_unit, paction->id,
+      if (action_prob_possible(action_prob_vs_tile(nmap, actor_unit, paction->id,
                                                    tgt_tile, tgt_extra))) {
         /* The actor unit may be able to do this action to the target
          * extra. */
@@ -1065,7 +1074,7 @@ action_auto_perf_unit_do(const enum action_auto_perf_cause cause,
         break;
       case ATK_SELF:
         if (actor
-            && is_action_enabled_unit_on_self(act, actor)) {
+            && is_action_enabled_unit_on_self(nmap, act, actor)) {
           perform_action_to(act, actor, actor->id, EXTRA_NONE);
         }
         break;
@@ -1129,39 +1138,39 @@ action_auto_perf_unit_prob(const enum action_auto_perf_cause cause,
       case ATK_UNITS:
         if (tgt_tile
             && is_action_enabled_unit_on_units(nmap, act, actor, tgt_tile)) {
-          current = action_prob_vs_units(actor, act, tgt_tile);
+          current = action_prob_vs_units(nmap, actor, act, tgt_tile);
         }
         break;
       case ATK_TILE:
         if (tgt_tile
             && is_action_enabled_unit_on_tile(nmap, act, actor,
                                               tgt_tile, target_extra)) {
-          current = action_prob_vs_tile(actor, act, tgt_tile, target_extra);
+          current = action_prob_vs_tile(nmap, actor, act, tgt_tile, target_extra);
         }
         break;
       case ATK_EXTRAS:
         if (tgt_tile
             && is_action_enabled_unit_on_extras(nmap, act, actor,
                                                 tgt_tile, target_extra)) {
-          current = action_prob_vs_extras(actor, act,
+          current = action_prob_vs_extras(nmap, actor, act,
                                           tgt_tile, target_extra);
         }
         break;
       case ATK_CITY:
         if (tgt_city
             && is_action_enabled_unit_on_city(nmap, act, actor, tgt_city)) {
-          current = action_prob_vs_city(actor, act, tgt_city);
+          current = action_prob_vs_city(nmap, actor, act, tgt_city);
         }
         break;
       case ATK_UNIT:
         if (tgt_unit
             && is_action_enabled_unit_on_unit(nmap, act, actor, tgt_unit)) {
-          current = action_prob_vs_unit(actor, act, tgt_unit);
+          current = action_prob_vs_unit(nmap, actor, act, tgt_unit);
         }
         break;
       case ATK_SELF:
         if (actor
-            && is_action_enabled_unit_on_self(act, actor)) {
+            && is_action_enabled_unit_on_self(nmap, act, actor)) {
           current = action_prob_self(actor, act);
         }
         break;
