@@ -20,6 +20,7 @@
 #include <QGridLayout>
 #include <QLineEdit>
 #include <QMenu>
+#include <QPushButton>
 #include <QSpinBox>
 #include <QToolButton>
 
@@ -36,12 +37,14 @@
 /**********************************************************************//**
   Setup edit_utype object
 **************************************************************************/
-edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : QDialog()
+edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : values_dlg()
 {
   QHBoxLayout *main_layout = new QHBoxLayout(this);
   QGridLayout *unit_layout = new QGridLayout();
   QLabel *label;
+  QPushButton *button;
   QMenu *req;
+  QMenu *menu;
   int row = 0;
   int rowcount;
   int column;
@@ -68,6 +71,24 @@ edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : QDialog
   unit_layout->addWidget(label, row, 0);
   unit_layout->addWidget(req_button, row++, 1);
 
+  label = new QLabel(QString::fromUtf8(R__("Class")));
+  label->setParent(this);
+  class_button = new QToolButton();
+  class_button->setParent(this);
+  class_button->setToolButtonStyle(Qt::ToolButtonTextOnly);
+  class_button->setPopupMode(QToolButton::MenuButtonPopup);
+  menu = new QMenu();
+  connect(menu, SIGNAL(triggered(QAction *)), this, SLOT(class_menu(QAction *)));
+
+  unit_class_re_active_iterate(pclass) {
+    menu->addAction(uclass_rule_name(pclass));
+  } unit_class_re_active_iterate_end;
+
+  class_button->setMenu(menu);
+
+  unit_layout->addWidget(label, row, 0);
+  unit_layout->addWidget(class_button, row++, 1);
+
   label = new QLabel(QString::fromUtf8(R__("Build Cost")));
   label->setParent(this);
 
@@ -187,6 +208,10 @@ edit_utype::edit_utype(ruledit_gui *ui_in, struct unit_type *utype_in) : QDialog
   unit_layout->addWidget(label, row, 0);
   unit_layout->addWidget(sound_fight_tag_alt, row++, 1);
 
+  button = new QPushButton(QString::fromUtf8(R__("Helptext")), this);
+  connect(button, SIGNAL(pressed()), this, SLOT(helptext()));
+  unit_layout->addWidget(button, row++, 1);
+
   rowcount = 0;
   column = 0;
   for (int i = 0; i < UTYF_LAST_USER_FLAG; i++) {
@@ -221,6 +246,8 @@ void edit_utype::closeEvent(QCloseEvent *cevent)
   int rowcount;
   int column;
 
+  close_help();
+
   // Save values from text fields.
   gfx_tag_given();
   gfx_tag_alt_given();
@@ -254,6 +281,7 @@ void edit_utype::closeEvent(QCloseEvent *cevent)
 void edit_utype::refresh()
 {
   req_button->setText(tab_tech::tech_name(utype->require_advance));
+  class_button->setText(uclass_rule_name(utype->uclass));
   bcost->setValue(utype->build_cost);
   attack->setValue(utype->attack_strength);
   defense->setValue(utype->defense_strength);
@@ -393,3 +421,27 @@ void edit_utype::sound_fight_tag_alt_given()
 
   sz_strlcpy(utype->sound_fight_alt, tag_bytes);
 }
+
+/**********************************************************************//**
+  User selected class
+**************************************************************************/
+void edit_utype::class_menu(QAction *action)
+{
+  QByteArray cn_bytes;
+  struct unit_class *pclass;
+
+  cn_bytes = action->text().toUtf8();
+  pclass = unit_class_by_rule_name(cn_bytes.data());
+
+  utype->uclass = pclass;
+
+  refresh();
+}
+
+/**********************************************************************//**
+  User pressed helptext button
+**************************************************************************/
+void edit_utype::helptext()
+{
+  open_help(&utype->helptext);
+}
